/**
 * Copyright (c) 2011-2012 EBM WebSourcing, 2012-2013 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.component.api;

import java.net.URL;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @author Marc Jambert - EBM WebSourcing
 */
public abstract class Configuration {

	private final String configurationName;
	private final Map<String, String> parameters;

	private final List<URL> resourceUrls;

	public Configuration(String configurationName) {
		assert configurationName != null;
		this.configurationName = configurationName;		
		this.parameters = new HashMap<String, String>();
		this.resourceUrls = new ArrayList<URL>();
	}

	public final String getConfigurationName() {
		return configurationName;
	}

	public final String[] getParameterNames() {
		return parameters.keySet().toArray(new String[parameters.size()]);
	}

	public final boolean hasParameter(String parameterName) {
		assert parameterName != null;
		return parameters.containsKey(parameterName);
	}

	public final String getParameter(String parameterName) {
		assert parameterName != null;
		return parameters.get(parameterName);
	}

	public final void setParameter(String parameterName, String parameterValue) {
		assert parameterName != null;
		assert parameterValue != null;
		parameters.put(parameterName, parameterValue);
	}

	public final void addResource(URL resourceUrl) {
		assert resourceUrl != null;
		resourceUrls.add(resourceUrl);
	}

	public final URL[] getResources() {
		return resourceUrls.toArray(new URL[resourceUrls.size()]);
	}

}
