/**
 * Copyright (c) 2011-2012 EBM WebSourcing, 2012-2013 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.component.api;

import java.net.URL;
import java.util.ArrayList;
import java.util.List;

import javax.xml.namespace.QName;

/**
 * @author Marc Jambert - EBM WebSourcing
 */
public final class ServiceConfiguration extends Configuration {

    public enum ServiceType {
        PROVIDE, CONSUME;
    }

    
    private final List<ServiceConfiguration> serviceConfigurationDependencies;

    private final ServiceType serviceType;

    private final QName interfaceQName;

    private final QName serviceQName;

    private final String endpointName;

    private final URL serviceDescription;

    public ServiceConfiguration(String configurationName, QName interfaceQName, QName serviceQName,
            String endpointName, ServiceType serviceType, URL serviceDescription) {
    	super(configurationName);
        assert interfaceQName != null;
        assert serviceQName != null;
        assert endpointName != null;
        assert serviceType != null;
		
        this.interfaceQName = interfaceQName;
        this.serviceQName = serviceQName;
        this.endpointName = endpointName;
        this.serviceType = serviceType;
        this.serviceDescription = serviceDescription;
        this.serviceConfigurationDependencies = new ArrayList<ServiceConfiguration>();
    }

    public ServiceConfiguration(String configurationName, QName interfaceName, QName serviceName,
            String endpointName, ServiceType serviceType) {
        this(configurationName, interfaceName, serviceName, endpointName, serviceType, null);
    }

    
    public ServiceType getServiceType() {
        return serviceType;
    }

    public final String getEndpointName() {
        return endpointName;
    }

    public URL getServiceDescription() {
        return serviceDescription;
    }

    public QName getInterfaceQName() {
        return interfaceQName;
    }

    public QName getServiceQName() {
        return serviceQName;
    }

    public void addServiceConfigurationDependency(ServiceConfiguration serviceConfiguration) {
        assert serviceConfiguration != null;
        this.serviceConfigurationDependencies.add(serviceConfiguration);
    }

    public ServiceConfiguration getServiceConfigurationDependency(int index) {
        return this.serviceConfigurationDependencies.get(index);
    }

    /**
     * @return a copy of service dependencies {@link List}
     */
    public ServiceConfiguration[] getServiceConfigurationDependencies() {
        return this.serviceConfigurationDependencies.toArray(new ServiceConfiguration[this.serviceConfigurationDependencies
                .size()]);
    }

}
